@@ -104,16 +104,25 @@ def install_requirements():
         the folder where all the repos are with the help of reqgen,
         merges them into one single requirements.txt, and installs them.
     """
+    non_recursive = os.environ.get('REQUIREMENTS_NON_RECURSIVE', False)
     home = os.environ.get("ODOO_HOME", '/home/odoo')
     instance = os.path.join(home, 'instance')
+    if non_recursive:
+        main_app = os.environ.get("MAIN_REPO_PATH", False)
+        if not main_app:
+            raise ValueError('To use REQUIREMENTS_NON_RECURSIVE you need to set MAIN_REPO_PATH')
+        instance = os.path.join(instance, main_app)
     full = os.path.join(home, 'full_requirements.txt')
     repo_path = os.path.join(instance, os.environ.get("MAIN_REPO_PATH"))
     exclude_path = os.path.join(repo_path, 'requirements_exclude.txt')
     if not os.path.exists(exclude_path):
         exclude_path = False
-    reqgen.generate_merged_file(full, instance, exclude=exclude_path)
-    cmd = 'pip install -r %s' % (full)
-    subprocess.check_call(shlex.split(cmd))
+
+    reqgen.generate_merged_file(full, instance, recursive=non_recursive, exclude=exclude_path)
+    if os.path.exists(full):
+        cmd = 'pip install -r %s' % (full)
+        subprocess.check_call(shlex.split(cmd))
+
     # Uninstall the requirements_exclude.txt if the path exists.
     if exclude_path:
         un_cmd = 'pip uninstall -r %s -yy' % (exclude_path)
